/*{
	"DESCRIPTION": "Doorway Transition",
	"CREDIT": "by IMIMOT - ported from http://transitions.glsl.io/transition/979934722820b5e715fa",
	"CATEGORIES": [
		"MIX", "Transition"
	],
	"INPUTS": [
		{
			"NAME": "inputImage",
			"TYPE": "image"
		},
		{
			"NAME": "targetImage",
			"TYPE": "image"
		},
		{
			"NAME": "fade",
			"TYPE": "float",
			"DEFAULT": 0.0,
			"MIN": 0.0,
			"MAX": 1.0
		},
		{
			"NAME": "depth",
			"TYPE": "float",
			"DEFAULT": 2.0,
			"MIN": 0.0,
			"MAX": 5.0
		}
	]
	
}*/

const vec4 black = vec4(0.0, 0.0, 0.0, 1.0);
const vec2 boundMin = vec2(0.0, 0.0);
const vec2 boundMax = vec2(1.0, 1.0);
 
bool inBounds (vec2 p) {
  return all(lessThan(boundMin, p)) && all(lessThan(p, boundMax));
}
 
vec2 project (vec2 p) {
  return p * vec2(1.0, -1.2) + vec2(0.0, -0.02);
}
 
vec4 bgColor (vec2 p, vec2 pto) {
  vec4 c = black;
  pto = project(pto);
  if (inBounds(pto)) {
    c += mix(black, IMG_NORM_PIXEL(targetImage, pto), 0.0 * mix(1.0, 0.0, pto.y));
  }
  return c;
}

void main()	{

  vec2 p = vv_FragNormCoord;

  vec2 pfr = vec2(-1.), pto = vec2(-1.);
 
  float middleSlit = 2.0 * abs(p.x-0.5) - fade;
  if (middleSlit > 0.0) {
    pfr = p + (p.x > 0.5 ? -1.0 : 1.0) * vec2(0.5*fade, 0.0);
    float d = 1.0/1.0;
    pfr.y -= d/2.;
    pfr.y *= d;
    pfr.y += d/2.;
  }
 
  float size = mix(1.0, depth, 1.-fade);
  pto = (p + vec2(-0.5, -0.5)) * vec2(size, size) + vec2(0.5, 0.5);
 
  if (inBounds(pfr)) {
    gl_FragColor = IMG_NORM_PIXEL(inputImage, pfr);
  }
  else if (inBounds(pto)) {
    gl_FragColor = IMG_NORM_PIXEL(targetImage, pto);
  }
  else {
    gl_FragColor = bgColor(p, pto);
  }

}
